@@ -31,6 +31,8 @@ __all__ = [
     "PolygonAnnotation",
     "PolygonPrediction",
     "Quaternion",
+    "SceneCategoryAnnotation",
+    "SceneCategoryPrediction",
     "Segment",
     "SegmentationAnnotation",
     "SegmentationPrediction",
@@ -61,6 +63,7 @@ from .annotation import (
     Point,
     Point3D,
     PolygonAnnotation,
+    SceneCategoryAnnotation,
     Segment,
     SegmentationAnnotation,
 )
@@ -132,6 +135,7 @@ from .prediction import (
     KeypointsPrediction,
     LinePrediction,
     PolygonPrediction,
+    SceneCategoryPrediction,
     SegmentationPrediction,
 )
 from .quaternion import Quaternion
@@ -235,6 +239,12 @@ class NucleusClient:
         """
         return self.list_jobs()
 
+    @property
+    def slices(self) -> List[Slice]:
+        response = self.make_request({}, "slice/", requests.get)
+        slices = [Slice.from_request(info, self) for info in response]
+        return slices
+
     @deprecated(msg="Use the NucleusClient.models property in the future.")
     def list_models(self) -> List[Model]:
         return self.models
@@ -441,7 +451,8 @@ class NucleusClient:
         Deletes a dataset by ID.
 
         All items, annotations, and predictions associated with the dataset will
-        be deleted as well.
+        be deleted as well. Note that if this dataset is linked to a Scale or Rapid
+        labeling project, the project itself will not be deleted.
 
         Parameters:
             dataset_id: The ID of the dataset to delete.
@@ -1020,6 +1031,7 @@ class NucleusClient:
         payload: Optional[dict],
         route: str,
         requests_command=requests.post,
+        return_raw_response: bool = False,
     ) -> dict:
         """Makes a request to a Nucleus API endpoint.
 
@@ -1029,9 +1041,10 @@ class NucleusClient:
             payload: Given request payload.
             route: Route for the request.
             Requests command: ``requests.post``, ``requests.get``, or ``requests.delete``.
+            return_raw_response: return the request's response object entirely
 
         Returns:
-            Response payload as JSON dict.
+            Response payload as JSON dict or request object.
         """
         if payload is None:
             payload = {}
@@ -1041,18 +1054,7 @@ class NucleusClient:
                     "Received defined payload with GET request! Will ignore payload"
                 )
             payload = None
-        return self._connection.make_request(payload, route, requests_command)  # type: ignore
-
-    def handle_bad_response(
-        self,
-        endpoint,
-        requests_command,
-        requests_response=None,
-        aiohttp_response=None,
-    ):
-        self._connection.handle_bad_response(
-            endpoint, requests_command, requests_response, aiohttp_response
-        )
+        return self._connection.make_request(payload, route, requests_command, return_raw_response)  # type: ignore
 
     def _set_api_key(self, api_key):
         """Fetch API key from environment variable NUCLEUS_API_KEY if not set"""
