@@ -139,11 +139,21 @@ class DatasetItem:  # pylint: disable=R0902
         image_url = payload.get(IMAGE_URL_KEY, None) or payload.get(
             ORIGINAL_IMAGE_URL_KEY, None
         )
+        pointcloud_url = payload.get(POINTCLOUD_URL_KEY, None)
+
+        # handle case when re-converting Scene.from_json
+        url = payload.get(URL_KEY, None)
+        if url and not image_url and not pointcloud_url:
+            if url.split(".")[-1] in ("jpg", "png"):
+                image_url = url
+            elif url.split(".")[-1] in ("json",):
+                pointcloud_url = url
+
         if BACKEND_REFERENCE_ID_KEY in payload:
             payload[REFERENCE_ID_KEY] = payload[BACKEND_REFERENCE_ID_KEY]
         return cls(
             image_location=image_url,
-            pointcloud_location=payload.get(POINTCLOUD_URL_KEY, None),
+            pointcloud_location=pointcloud_url,
             reference_id=payload.get(REFERENCE_ID_KEY, None),
             metadata=payload.get(METADATA_KEY, {}),
             upload_to_scale=payload.get(UPLOAD_TO_SCALE_KEY, True),
@@ -195,13 +205,17 @@ def check_all_paths_remote(dataset_items: Sequence[DatasetItem]):
 def check_for_duplicate_reference_ids(dataset_items: Sequence[DatasetItem]):
     ref_ids = []
     for dataset_item in dataset_items:
-        if dataset_item.reference_id is not None:
-            ref_ids.append(dataset_item.reference_id)
+        if dataset_item.reference_id is None:
+            raise ValueError(
+                f"Reference ID cannot be None. Encountered DatasetItem with no reference ID:\n{dataset_item}"
+            )
+        ref_ids.append(dataset_item.reference_id)
     if len(ref_ids) != len(set(ref_ids)):
         duplicates = {
             f"{key}": f"Count: {value}"
             for key, value in Counter(ref_ids).items()
+            if value > 1
         }
         raise ValueError(
-            f"Duplicate reference ids found among dataset_items: {duplicates}"
+            f"Duplicate reference IDs found among dataset_items: {duplicates}"
         )
