@@ -5,3 +5,7 @@ class PolygonAnnotationTypeError(Exception):
     ):
         self.message = message
         super().__init__(self.message)
+
+
+class EverythingFilteredError(Exception):
+    pass
