@@ -8,12 +8,11 @@ from nucleus.annotation import AnnotationList, BoxAnnotation, PolygonAnnotation
 from nucleus.prediction import BoxPrediction, PolygonPrediction, PredictionList
 
 from .base import Metric, ScalarResult
+from .custom_types import BoxOrPolygonAnnotation, BoxOrPolygonPrediction
 from .filtering import ListOfAndFilters, ListOfOrAndFilters
 from .filters import confidence_filter, polygon_label_filter
 from .metric_utils import compute_average_precision
 from .polygon_utils import (
-    BoxOrPolygonAnnotation,
-    BoxOrPolygonPrediction,
     get_true_false_positives_confidences,
     group_boxes_or_polygons_by_label,
     iou_assignments,
@@ -542,8 +541,11 @@ class PolygonAveragePrecision(PolygonMetric):
         ) = get_true_false_positives_confidences(
             annotations_filtered, predictions_filtered, self.iou_threshold
         )
-        idxes = np.argsort(-confidences)
-        true_false_positives_sorted = true_false_positives[idxes]
+        if np.all(confidences):
+            idxes = np.argsort(-confidences)
+            true_false_positives_sorted = true_false_positives[idxes]
+        else:
+            true_false_positives_sorted = true_false_positives
         cumulative_true_positives = np.cumsum(true_false_positives_sorted)
         total_predictions = np.arange(1, len(true_false_positives) + 1)
         precisions = cumulative_true_positives / total_predictions
