@@ -8,7 +8,7 @@ For example::
     client = nucleus.NucleusClient(YOUR_SCALE_API_KEY)
     prediction_1 = nucleus.BoxPrediction(label="label", x=0, y=0, width=10, height=10, reference_id="1", confidence=0.9, class_pdf={'label': 0.9, 'other_label': 0.1})
     prediction_2 = nucleus.BoxPrediction(label="label", x=0, y=0, width=10, height=10, reference_id="2", confidence=0.2, class_pdf={'label': 0.2, 'other_label': 0.8})
-    model = client.add_model(name="My Model", reference_id="My-CNN", metadata={"timestamp": "121012401"})
+    model = client.create_model(name="My Model", reference_id="My-CNN", metadata={"timestamp": "121012401"})
     response = dataset.upload_predictions(model, [prediction_1, prediction_2])
 """
 
@@ -154,6 +154,11 @@ class ModelRun:
             "predictions_ignored": int,
         }
         """
+        uploader = PredictionUploader(
+            model_run_id=self.model_run_id, client=self._client
+        )
+        uploader.check_for_duplicate_ids(annotations)
+
         if asynchronous:
             check_all_mask_paths_remote(annotations)
 
@@ -165,9 +170,7 @@ class ModelRun:
                 route=f"modelRun/{self.model_run_id}/predict?async=1",
             )
             return AsyncJob.from_json(response, self._client)
-        uploader = PredictionUploader(
-            model_run_id=self.model_run_id, client=self._client
-        )
+
         return uploader.upload(
             annotations=annotations,
             update=update,
