@@ -16,6 +16,7 @@ from .annotation import (
     Point,
     Point3D,
     PolygonAnnotation,
+    SceneCategoryAnnotation,
     Segment,
     SegmentationAnnotation,
 )
@@ -75,7 +76,7 @@ class SegmentationPrediction(SegmentationAnnotation):
         from nucleus import SegmentationPrediction
 
         segmentation = SegmentationPrediction(
-            mask_url="s3://your-bucket-name/pred-seg-masks/image_2_pred_mask_id1.png",
+            mask_url="s3://your-bucket-name/pred-seg-masks/image_2_pred_mask_id_1.png",
             annotations=[
                 Segment(label="grass", index="1"),
                 Segment(label="road", index="2"),
@@ -88,7 +89,7 @@ class SegmentationPrediction(SegmentationAnnotation):
 
     Parameters:
         mask_url (str): A URL pointing to the segmentation prediction mask which is
-          accessible to Scale. This URL can be a path to a local file.
+          accessible to Scale. This "URL" can also be a path to a local file.
           The mask is an HxW int8 array saved in PNG format,
           with each pixel value ranging from [0, N), where N is the number of
           possible classes (for semantic segmentation) or instances (for instance
@@ -226,7 +227,7 @@ class LinePrediction(LineAnnotation):
 
     Parameters:
         label (str): The label for this prediction (e.g. car, pedestrian, bicycle).
-        vertices List[:class:`Point`]: The list of points making up the line.
+        vertices (List[:class:`Point`]): The list of points making up the line.
         reference_id (str): User-defined ID of the image to which to apply this
             annotation.
         confidence: 0-1 indicating the confidence of the prediction.
@@ -571,6 +572,17 @@ class CategoryPrediction(CategoryAnnotation):
         )
 
 
+class SceneCategoryPrediction(SceneCategoryAnnotation):
+    """A prediction of a category for a scene.
+
+    Parameters:
+        label: The label for this annotation (e.g. action, subject, scenario).
+        reference_id: The reference ID of the scene you wish to apply this annotation to.
+        taxonomy_name: The name of the taxonomy this annotation conforms to.
+          See :meth:`Dataset.add_taxonomy`.
+    """
+
+
 Prediction = Union[
     BoxPrediction,
     LinePrediction,
@@ -578,6 +590,7 @@ Prediction = Union[
     KeypointsPrediction,
     CuboidPrediction,
     CategoryPrediction,
+    SceneCategoryPrediction,
     SegmentationPrediction,
 ]
 
@@ -596,6 +609,9 @@ class PredictionList:
     category_predictions: List[CategoryPrediction] = field(
         default_factory=list
     )
+    scene_category_predictions: List[SceneCategoryPrediction] = field(
+        default_factory=list
+    )
     segmentation_predictions: List[SegmentationPrediction] = field(
         default_factory=list
     )
@@ -617,6 +633,8 @@ class PredictionList:
                 self.cuboid_predictions.append(prediction)
             elif isinstance(prediction, CategoryPrediction):
                 self.category_predictions.append(prediction)
+            elif isinstance(prediction, SceneCategoryPrediction):
+                self.scene_category_predictions.append(prediction)
             else:
                 assert isinstance(
                     prediction, SegmentationPrediction
@@ -631,5 +649,6 @@ class PredictionList:
             + len(self.keypoints_predictions)
             + len(self.cuboid_predictions)
             + len(self.category_predictions)
+            + len(self.scene_category_predictions)
             + len(self.segmentation_predictions)
         )
